@@ -20,6 +20,7 @@ from param.parameterized import ParameterizedMetaclass
 
 from .config import config
 from .io.datamodel import construct_data_model
+from .io.resources import component_resource_path
 from .io.state import state
 from .models import (
     AnyWidgetComponent as _BkAnyWidgetComponent,
@@ -223,7 +224,7 @@ class ReactiveESM(ReactiveCustomBase, metaclass=ReactiveESMMetaclass):
     # 3. Named export (`{ <export>, ... }`): ("<export>", ...)
     _exports__: ClassVar[ExportSpec] = {}
 
-    _importmap: ClassVar[dict[Literal['imports', 'scopes'], str]] = {}
+    _importmap: ClassVar[dict[Literal['imports', 'scopes'], dict[str,str]]] = {}
 
     __abstract = True
 
@@ -235,7 +236,7 @@ class ReactiveESM(ReactiveCustomBase, metaclass=ReactiveESMMetaclass):
 
     @classproperty
     def _bundle_path(cls) -> os.PathLike | None:
-        if config.autoreload:
+        if config.autoreload and cls._esm:
             return
         try:
             mod_path = pathlib.Path(inspect.getfile(cls)).parent
@@ -272,7 +273,7 @@ class ReactiveESM(ReactiveCustomBase, metaclass=ReactiveESMMetaclass):
 
     @classmethod
     def _esm_path(cls, compiled: bool = True) -> os.PathLike | None:
-        if compiled:
+        if compiled or not cls._esm:
             bundle_path = cls._bundle_path
             if bundle_path:
                 return bundle_path
@@ -294,9 +295,22 @@ class ReactiveESM(ReactiveCustomBase, metaclass=ReactiveESMMetaclass):
         return
 
     @classmethod
-    def _render_esm(cls, compiled: bool | Literal['compiling'] = True):
-        if (esm_path:= cls._esm_path(compiled=compiled is True)):
-            esm = esm_path.read_text(encoding='utf-8')
+    def _render_esm(cls, compiled: bool | Literal['compiling'] = True, server: bool = False):
+        esm_path = cls._esm_path(compiled=compiled is True)
+        if esm_path:
+            if esm_path == cls._bundle_path and cls.__module__ in sys.modules and server:
+                base_cls = cls
+                for scls in cls.__mro__[1:][::-1]:
+                    if not issubclass(scls, ReactiveESM):
+                        continue
+                    if esm_path == scls._esm_path(compiled=compiled is True):
+                        base_cls = scls
+                esm = component_resource_path(base_cls, '_bundle_path', esm_path)
+                if config.autoreload:
+                    modified = hashlib.sha256(str(esm_path.stat().st_mtime).encode('utf-8')).hexdigest()
+                    esm += f'?{modified}'
+            else:
+                esm = esm_path.read_text(encoding='utf-8')
         else:
             esm = cls._esm
         esm = textwrap.dedent(esm)
@@ -329,8 +343,12 @@ class ReactiveESM(ReactiveCustomBase, metaclass=ReactiveESMMetaclass):
             self._update_esm()
 
     def _update_esm(self):
-        esm = self._render_esm(not config.autoreload)
         for ref, (model, _) in self._models.copy().items():
+            if ref not in state._views:
+                continue
+            doc = state._views[ref][2]
+            is_session = doc.session_context and doc.session_context.server_context
+            esm = self._render_esm(not config.autoreload, server=is_session)
             if esm == model.esm:
                 continue
             self._apply_update({}, {'esm': esm}, model, ref)
@@ -339,42 +357,43 @@ class ReactiveESM(ReactiveCustomBase, metaclass=ReactiveESMMetaclass):
     def _linked_properties(self) -> list[str]:
         return [p for p in self._data_model.properties() if p not in ('js_property_callbacks',)]
 
-    def _init_params(self) -> dict[str, Any]:
+    def _get_properties(self, doc: Document) -> dict[str, Any]:
+        props = super()._get_properties(doc)
         cls = type(self)
-        ignored = [p for p in Reactive.param if not issubclass(cls.param[p].owner, ReactiveESM)]
-        params = {
-            p : getattr(self, p) for p in list(Layoutable.param)
-            if getattr(self, p) is not None and p != 'name'
-        }
         data_params = {}
+        ignored = [p for p in Reactive.param if not issubclass(cls.param[p].owner, ReactiveESM)]
         for k, v in self.param.values().items():
-            if (
-                (k in ignored and k != 'name') or
-                (((p:= self.param[k]).precedence or 0) < 0) or
-                is_viewable_param(p)
-            ):
+            p = self.param[k]
+            is_viewable = is_viewable_param(p)
+            if (k in ignored and k != 'name') or ((p.precedence or 0) < 0) or is_viewable:
+                if is_viewable and k in props:
+                    props.pop(k)
                 continue
-            if k in params:
-                params.pop(k)
+            if k in props:
+                props.pop(k)
             data_params[k] = v
         bundle_path = self._bundle_path
+        importmap = self._process_importmap()
+        is_session = False
         if bundle_path:
-            bundle_hash = hashlib.sha256(str(bundle_path).encode('utf-8')).hexdigest()
-            importmap = {}
+            is_session = (doc.session_context and doc.session_context.server_context)
+            if bundle_path == self._esm_path(not config.autoreload) and cls.__module__ in sys.modules and is_session:
+                bundle_hash = 'url'
+            else:
+                bundle_hash = hashlib.sha256(str(bundle_path).encode('utf-8')).hexdigest()
         else:
             bundle_hash = None
-            importmap = self._process_importmap()
         data_props = self._process_param_change(data_params)
-        params.update({
+        props.update({
             'bundle': bundle_hash,
             'class_name': camel_to_kebab(cls.__name__),
             'data': self._data_model(**{p: v for p, v in data_props.items() if p not in ignored}),
             'dev': config.autoreload or getattr(self, '_debug', False),
-            'esm': self._render_esm(not config.autoreload),
+            'esm': self._render_esm(not config.autoreload, server=is_session),
             'importmap': importmap,
             'name': cls.__name__
         })
-        return params
+        return props
 
     @classmethod
     def _process_importmap(cls):
@@ -614,14 +633,14 @@ class ReactComponent(ReactiveESM):
         }
         if any('@mui' in v for v in imports.values()):
             exports.update({
-                "@emotion/cache": "createCache",
-                "@emotion/react": ("CacheProvider",)
+                "@emotion/cache": ["createCache"],
+                "@emotion/react": [("CacheProvider",)],
             })
         return exports
 
     @classmethod
-    def _render_esm(cls, compiled: bool | Literal['compiling'] = True):
-        esm = super()._render_esm(compiled=compiled)
+    def _render_esm(cls, compiled: bool | Literal['compiling'] = True, server: bool = False):
+        esm = super()._render_esm(compiled=compiled, server=server)
         if compiled == 'compiling':
             esm = 'import * as React from "react"\n' + esm
         return esm
