@@ -2,7 +2,6 @@ from __future__ import annotations
 
 import base64
 import concurrent.futures
-import dataclasses
 import json
 import os
 import pathlib
@@ -12,7 +11,6 @@ from typing import IO, Any, Literal
 
 import bokeh
 
-from bokeh.application.application import SessionContext
 from bokeh.application.handlers.code import CodeHandler
 from bokeh.core.json_encoder import serialize_json
 from bokeh.core.templates import FILE, MACROS, get_env
@@ -25,6 +23,7 @@ from bokeh.util.serialization import make_id
 from .. import __version__, config
 from ..util import base_version, escape
 from .application import Application, build_single_handler_application
+from .document import MockSessionContext
 from .loading import LOADING_INDICATOR_CSS_CLASS
 from .mime_render import find_requirements
 from .resources import (
@@ -41,8 +40,8 @@ WORKER_HANDLER_TEMPLATE  = _pn_env.get_template('pyodide_handler.js')
 PANEL_ROOT = pathlib.Path(__file__).parent.parent
 BOKEH_VERSION = base_version(bokeh.__version__)
 PY_VERSION = base_version(__version__)
-PYODIDE_VERSION = 'v0.25.0'
-PYSCRIPT_VERSION = '2024.2.1'
+PYODIDE_VERSION = 'v0.26.2'
+PYSCRIPT_VERSION = '2024.8.1'
 WHL_PATH = DIST_DIR / 'wheels'
 PANEL_LOCAL_WHL = WHL_PATH / f'panel-{__version__.replace("-dirty", "")}-py3-none-any.whl'
 BOKEH_LOCAL_WHL = WHL_PATH / f'bokeh-{BOKEH_VERSION}-py3-none-any.whl'
@@ -121,32 +120,6 @@ if ('serviceWorker' in navigator) {
 </script>
 """
 
-@dataclasses.dataclass
-class Request:
-    headers : dict
-    cookies : dict
-    arguments : dict
-
-
-class MockSessionContext(SessionContext):
-
-    def __init__(self, *args, document=None, **kwargs):
-        self._document = document
-        super().__init__(*args, server_context=None, session_id=None, **kwargs)
-
-    def with_locked_document(self, *args):
-        return
-
-    @property
-    def destroyed(self) -> bool:
-        return False
-
-    @property
-    def request(self):
-        return Request(headers={}, cookies={}, arguments={})
-
-
-
 def make_index(files, title=None, manifest=True):
     if manifest:
         manifest = 'site.webmanifest'
@@ -272,7 +245,6 @@ def script_to_html(
     reqs = base_reqs + [
         req for req in requirements if req not in ('panel', 'bokeh')
     ]
-    print(reqs)
     for name, min_version in MINIMUM_VERSIONS.items():
         if any(name in req for req in reqs):
             reqs = [f'{name}>={min_version}' if name in req else req for req in reqs]
@@ -290,17 +262,17 @@ def script_to_html(
             css_resources = [PYSCRIPT_CSS, PYSCRIPT_CSS_OVERRIDES]
         elif not css_resources:
             css_resources = []
-        pyconfig = json.dumps({'packages': reqs, 'plugins': ["!error"]})
+        pyconfig = json.dumps({'packages': reqs})
         if 'worker' in runtime:
             plot_script = f'<script type="py" async worker config=\'{pyconfig}\' src="{app_name}.py"></script>'
             web_worker = code
         else:
-            plot_script = f'<py-script config=\'{pyconfig}\'>{code}</py-script>'
+            plot_script = f'<script type=\'py\' config=\'{pyconfig}\'>{code}</script>'
     else:
         if css_resources == 'auto':
             css_resources = []
         env_spec = ', '.join([repr(req) for req in reqs])
-        code = code.encode("unicode_escape").decode("utf-8").replace('`', '\`')
+        code = code.encode("unicode_escape").decode("utf-8").replace('`', r'\`')
         if runtime == 'pyodide-worker':
             if js_resources == 'auto':
                 js_resources = []
@@ -549,7 +521,7 @@ def convert_apps(
     compiled: bool
         Whether to use the compiled and faster version of Pyodide.
     """
-    if isinstance(apps, str):
+    if isinstance(apps, (str, os.PathLike)):
         apps = [apps]
     if dest_path is None:
         dest_path = pathlib.Path('./')
@@ -564,7 +536,7 @@ def convert_apps(
         for app in apps:
             matches = [
                 deps for name, deps in requirements.items()
-                if app.endswith(name.replace(os.path.sep, '/'))
+                if str(app).endswith(name.replace(os.path.sep, '/'))
             ]
             app_requirements[app] = matches[0] if matches else 'auto'
     else:
