@@ -596,7 +596,7 @@ class ComponentResourceHandler(StaticFileHandler):
 
     _resource_attrs = [
         '__css__', '__javascript__', '__js_module__', '__javascript_modules__',  '_resources',
-        '_css', '_js', 'base_css', 'css', '_stylesheets', 'modifiers'
+        '_css', '_js', 'base_css', 'css', '_stylesheets', 'modifiers', '_bundle_path'
     ]
 
     def initialize(self, path: Optional[str] = None, default_filename: Optional[str] = None):
@@ -703,7 +703,7 @@ def serve(
 
     Arguments
     ---------
-    panel: Viewable, function or {str: Viewable or function}
+    panels: Viewable, function or {str: Viewable or function}
       A Panel object, a function returning a Panel object or a
       dictionary mapping from the URL slug to either.
     port: int (optional, default=0)
@@ -825,7 +825,7 @@ def get_server(
     oauth_encryption_key: Optional[str] = None,
     oauth_jwt_user: Optional[str] = None,
     oauth_refresh_tokens: Optional[bool] = None,
-    oauth_guest_endpoints: Optional[bool] = None,
+    oauth_guest_endpoints: Optional[list[str]] = None,
     oauth_optional: Optional[bool] = None,
     login_endpoint: Optional[str] = None,
     logout_endpoint: Optional[str] = None,
@@ -1021,7 +1021,8 @@ def get_server(
             logout_endpoint=logout_endpoint,
             login_template=login_template,
             logout_template=logout_template,
-            error_template=oauth_error_template
+            error_template=oauth_error_template,
+            guest_endpoints=oauth_guest_endpoints,
         )
     if oauth_key:
         config.oauth_key = oauth_key # type: ignore
