@@ -1,15 +1,17 @@
-import {div} from "@bokehjs/core/dom"
+import {div, px} from "@bokehjs/core/dom"
 import {isArray} from "@bokehjs/core/util/types"
+import {unreachable} from "@bokehjs/core/util/assert"
 import {WidgetView} from "@bokehjs/models/widgets/widget"
 import type {Markup} from "@bokehjs/models/widgets/markup"
 import {LayoutDOM, LayoutDOMView} from "@bokehjs/models/layouts/layout_dom"
+import type {UIElement} from "@bokehjs/models/ui/ui_element"
 import type * as p from "@bokehjs/core/properties"
 
 export class PanelMarkupView extends WidgetView {
   declare model: Markup
 
   container: HTMLDivElement
-  _initialized_stylesheets: any
+  protected _initialized_stylesheets: Map<string, boolean>
 
   override connect_signals(): void {
     super.connect_signals()
@@ -33,28 +35,28 @@ export class PanelMarkupView extends WidgetView {
   }
 
   watch_stylesheets(): void {
-    this._initialized_stylesheets = {}
-    for (const sts of this._applied_stylesheets) {
-      const style_el = (sts as any).el
+    this._initialized_stylesheets = new Map()
+    for (const stylesheet of this._applied_stylesheets) {
+      // @ts-expect-error: 'el' is protected
+      const style_el = stylesheet.el
       if (style_el instanceof HTMLLinkElement) {
-        this._initialized_stylesheets[style_el.href] = false
+        this._initialized_stylesheets.set(style_el.href, false)
         style_el.addEventListener("load", () => {
-          this._initialized_stylesheets[style_el.href] = true
-          if (Object.values(this._initialized_stylesheets).every(Boolean)) {
+          this._initialized_stylesheets.set(style_el.href, true)
+          if ([...this._initialized_stylesheets.values()].every((v) => v)) {
             this.style_redraw()
           }
         })
       }
     }
-    if (Object.keys(this._initialized_stylesheets).length === 0) {
+    if (this._initialized_stylesheets.size == 0) {
       this.style_redraw()
     }
   }
 
-  style_redraw(): void {
-  }
+  style_redraw(): void {}
 
-  has_math_disabled() {
+  has_math_disabled(): boolean {
     return this.model.disable_math || !this.contains_tex_string(this.model.text)
   }
 
@@ -71,7 +73,7 @@ export class PanelMarkupView extends WidgetView {
   }
 }
 
-export function set_size(el: HTMLElement, model: HTMLBox, adjustMargin: boolean = true): void {
+export function set_size(el: HTMLElement, model: HTMLBox, adjust_margin: boolean = true): void {
   let width_policy = model.width != null ? "fixed" : "fit"
   let height_policy = model.height != null ? "fixed" : "fit"
   const {sizing_mode, margin} = model
@@ -86,67 +88,73 @@ export function set_size(el: HTMLElement, model: HTMLBox, adjustMargin: boolean
       height_policy = "max"
     } else {
       switch (sizing_mode) {
-        case "scale_width":
+        case "scale_width": {
           width_policy = "max"
           height_policy = "min"
           break
-        case "scale_height":
+        }
+        case "scale_height": {
           width_policy = "min"
           height_policy = "max"
           break
-        case "scale_both":
+        }
+        case "scale_both": {
           width_policy = "max"
           height_policy = "max"
           break
-        default:
-          throw new Error("unreachable")
+        }
+        default: {
+          unreachable()
+        }
       }
     }
   }
   let wm: number, hm: number
-  if (!adjustMargin) {
+  if (!adjust_margin) {
     hm = wm = 0
   } else if (isArray(margin)) {
     if (margin.length === 4) {
       hm = margin[0] + margin[2]
       wm = margin[1] + margin[3]
     } else {
-      hm = margin[0] * 2
-      wm = margin[1] * 2
+      hm = margin[0]*2
+      wm = margin[1]*2
     }
   } else if (margin == null) {
     hm = wm = 0
   } else {
-    wm = hm = margin * 2
+    wm = hm = margin*2
   }
-  if (width_policy == "fixed" && model.width) {
-    el.style.width = `${model.width}px`
+
+  if (width_policy == "fixed" && model.width != null) {
+    el.style.width = px(model.width)
   } else if (width_policy == "max") {
-    el.style.width = wm ? `calc(100% - ${wm}px)`: "100%"
+    el.style.width = wm != 0 ? `calc(100% - ${px(wm)})` : "100%"
   }
   if (model.min_width != null) {
-    el.style.minWidth = `${model.min_width}px`
+    el.style.minWidth = px(model.min_width)
   }
   if (model.max_width != null) {
-    el.style.maxWidth = `${model.max_width}px`
+    el.style.maxWidth = px(model.max_width)
   }
-  if (height_policy == "fixed" && model.height) {
-    el.style.height = `${model.height}px`
+
+  if (height_policy == "fixed" && model.height != null) {
+    el.style.height = px(model.height)
   } else if (height_policy == "max") {
-    el.style.height = hm ? `calc(100% - ${hm}px)`: "100%"
+    el.style.height = hm != 0 ? `calc(100% - ${px(hm)})` : "100%"
   }
   if (model.min_height != null) {
-    el.style.minHeight = `${model.min_height}px`
+    el.style.minHeight = px(model.min_height)
   }
-  if (model.max_width != null) {
-    el.style.maxHeight = `${model.max_height}px`
+  if (model.max_height != null) {
+    el.style.maxHeight = px(model.max_height)
   }
 }
 
 export abstract class HTMLBoxView extends LayoutDOMView {
   declare model: HTMLBox
 
-  _initialized_stylesheets: any
+  protected _initialized_stylesheets: Map<string, boolean>
 
   override connect_signals(): void {
     super.connect_signals()
@@ -162,14 +170,15 @@ export abstract class HTMLBoxView extends LayoutDOMView {
   }
 
   watch_stylesheets(): void {
-    this._initialized_stylesheets = {}
-    for (const sts of this._applied_stylesheets) {
-      const style_el = (sts as any).el
+    this._initialized_stylesheets = new Map()
+    for (const stylesheet of this._applied_stylesheets) {
+      // @ts-expect-error: 'el' is protected
+      const style_el = stylesheet.el
       if (style_el instanceof HTMLLinkElement) {
-        this._initialized_stylesheets[style_el.href] = false
+        this._initialized_stylesheets.set(style_el.href, false)
         style_el.addEventListener("load", () => {
-          this._initialized_stylesheets[style_el.href] = true
-          if (Object.values(this._initialized_stylesheets).every(Boolean)) {
+          this._initialized_stylesheets.set(style_el.href, true)
+          if ([...this._initialized_stylesheets.values()].every((v) => v)) {
             this.style_redraw()
           }
         })
@@ -177,10 +186,9 @@ export abstract class HTMLBoxView extends LayoutDOMView {
     }
   }
 
-  style_redraw(): void {
-  }
+  style_redraw(): void {}
 
-  get child_models(): LayoutDOM[] {
+  get child_models(): UIElement[] {
     return []
   }
 }
