@@ -1,37 +1,43 @@
 import {select, option} from "@bokehjs/core/dom"
 import {isString} from "@bokehjs/core/util/types"
-import * as p from "@bokehjs/core/properties"
+import type * as p from "@bokehjs/core/properties"
 
 import {InputWidget, InputWidgetView} from "@bokehjs/models/widgets/input_widget"
 import * as inputs from "@bokehjs/styles/widgets/inputs.css"
 
 export class SingleSelectView extends InputWidgetView {
-  model: SingleSelect
+  declare model: SingleSelect
 
   declare input_el: HTMLSelectElement
 
-  connect_signals(): void {
+  override connect_signals(): void {
     super.connect_signals()
-    this.connect(this.model.properties.value.change, () => this.render_selection())
-    this.connect(this.model.properties.options.change, () => this.render())
-    this.connect(this.model.properties.disabled_options.change, () => this.render())
-    this.connect(this.model.properties.size.change, () => this.render())
-    this.connect(this.model.properties.disabled.change, () => this.render())
+
+    const {value, options, disabled_options, size, disabled} = this.model.properties
+    this.on_change(value, () => this.render_selection())
+    this.on_change(options, () => this.render())
+    this.on_change(disabled_options, () => this.render())
+    this.on_change(size, () => this.render())
+    this.on_change(disabled, () => this.render())
   }
 
-  render(): void {
+  override render(): void {
     super.render()
+    this.render_selection()
+  }
 
+  _render_input(): HTMLElement {
     const options = this.model.options.map((opt) => {
       let value, _label
-      if (isString(opt))
+      if (isString(opt)) {
         value = _label  = opt
-      else
+      } else {
         [value, _label] = opt
+      }
 
-      let disabled = this.model.disabled_options.includes(value)
+      const disabled = this.model.disabled_options.includes(value)
 
-      return option({value: value, disabled: disabled}, _label)
+      return option({value, disabled}, _label)
     })
 
     this.input_el = select({
@@ -40,31 +46,31 @@ export class SingleSelectView extends InputWidgetView {
       name: this.model.name,
       disabled: this.model.disabled,
     }, options)
-    this.input_el.style.backgroundImage = 'none';
+    this.input_el.style.backgroundImage = "none"
 
     this.input_el.addEventListener("change", () => this.change_input())
-    this.group_el.appendChild(this.input_el)
-
-    this.render_selection()
+    return this.input_el
   }
 
   render_selection(): void {
     const selected = this.model.value
 
-    for (const el of this.input_el.querySelectorAll('option'))
-      if (el.value === selected)
+    for (const el of this.input_el.querySelectorAll("option")) {
+      if (el.value === selected) {
         el.selected = true
+      }
+    }
 
     // Note that some browser implementations might not reduce
     // the number of visible options for size <= 3.
     this.input_el.size = this.model.size
   }
 
-  change_input(): void {
-    const is_focused = this.el.querySelector('select:focus') != null
+  override change_input(): void {
+    const is_focused = this.el.querySelector("select:focus") != null
 
     let value = null
-    for (const el of this.shadow_el.querySelectorAll('option')) {
+    for (const el of this.shadow_el.querySelectorAll("option")) {
       if (el.selected) {
         value = el.value
         break
@@ -77,8 +83,9 @@ export class SingleSelectView extends InputWidgetView {
     // so that even if python on_change callback is invoked,
     // focus remains on <select> and one can seamlessly scroll
     // up/down.
-    if (is_focused)
+    if (is_focused) {
       this.input_el.focus()
+    }
   }
 }
 
@@ -96,23 +103,23 @@ export namespace SingleSelect {
 export interface SingleSelect extends SingleSelect.Attrs {}
 
 export class SingleSelect extends InputWidget {
-  properties: SingleSelect.Props
-  __view_type__: SingleSelectView
+  declare properties: SingleSelect.Props
+  declare __view_type__: SingleSelectView
 
   constructor(attrs?: Partial<SingleSelect.Attrs>) {
     super(attrs)
   }
 
-  static __module__ = "panel.models.widgets"
+  static override __module__ = "panel.models.widgets"
 
   static {
     this.prototype.default_view = SingleSelectView
 
-    this.define<SingleSelect.Props>(({Any, Array, Int, Nullable, String}) => ({
-      disabled_options: [ Array(String), [] ],
-      options:          [ Array(Any), []    ],
+    this.define<SingleSelect.Props>(({Any, List, Int, Nullable, Str}) => ({
+      disabled_options: [ List(Str), [] ],
+      options:          [ List(Any), []    ],
       size:             [ Int,         4    ], // 4 is the HTML default
-      value:            [ Nullable(String),     null ],
+      value:            [ Nullable(Str),     null ],
     }))
   }
 }
