@@ -12,7 +12,7 @@ from bokeh.models.ui.icons import Icon
 from bokeh.models.widgets import (
     Button as bkButton, CheckboxButtonGroup as bkCheckboxButtonGroup,
     InputWidget, MultiSelect, RadioButtonGroup as bkRadioButtonGroup, Select,
-    TextAreaInput as BkTextAreaInput, Widget,
+    TextAreaInput as bkTextAreaInput, TextInput as bkTextInput, Widget,
 )
 
 from .layout import HTMLBox
@@ -31,6 +31,9 @@ class Player(Widget):
     """
     The Player widget provides controls to play through a number of frames.
     """
+    title = Nullable(String, default="", help="""
+    The slider's label (supports :ref:`math text <ug_styling_mathtext>`).
+    """)
 
     start = Int(0, help="Lower bound of the Player slider")
 
@@ -40,6 +43,9 @@ class Player(Widget):
 
     value_throttled = Int(0, help="Current throttled value of the player app")
 
+    value_align = String("start", help="""Location to display
+        the value of the slider ("start" "center", "end")""")
+
     step = Int(1, help="Number of steps to advance the player by.")
 
     interval = Int(500, help="Interval between updates")
@@ -53,10 +59,32 @@ class Player(Widget):
     show_loop_controls = Bool(True, help="""Whether the loop controls
         radio buttons are shown""")
 
+    preview_duration = Int(1500, help="""
+        Duration (in milliseconds) for showing the current FPS when clicking
+        the slower/faster buttons, before reverting to the icon.""")
+
+    show_value = Bool(True, help="""
+        Whether to show the widget value""")
+
     width = Override(default=400)
 
     height = Override(default=250)
 
+    scale_buttons = Float(1, help="Percentage to scale the size of the buttons by")
+
+    visible_buttons = List(String, default=[
+        'slower', 'first', 'previous', 'reverse', 'pause', 'play', 'next', 'last', 'faster'
+    ], help="The buttons to display on the player.")
+
+    visible_loop_options = List(String, default=[
+        'once', 'loop', 'reflect'
+    ], help="The loop options to display on the player.")
+
+class DiscretePlayer(Player):
+
+    options = List(Any, help="""
+        List of discrete options.""")
+
 
 class SingleSelect(InputWidget):
     ''' Single-select widget.
@@ -216,7 +244,7 @@ class TooltipIcon(Widget):
     )
 
 
-class TextAreaInput(BkTextAreaInput):
+class TextAreaInput(bkTextAreaInput):
 
     auto_grow = Bool(
         default=False,
@@ -268,3 +296,19 @@ class RadioButtonGroup(bkRadioButtonGroup):
     Delay (in milliseconds) to display the tooltip after the cursor has
     hovered over the Button, default is 500ms.
     """)
+
+
+class EnterEvent(ModelEvent):
+
+    event_name = 'enter-pressed'
+
+    def __init__(self, model, value_input):
+        self.value_input = value_input
+        super().__init__(model=model)
+
+    def __repr__(self):
+        return (
+            f'{type(self).__name__}(value_input={self.value_input})'
+        )
+
+class TextInput(bkTextInput): ...
