@@ -1,6 +1,7 @@
 import os
 import re
 import tempfile
+import time
 
 import pytest
 import requests
@@ -31,6 +32,31 @@ def test_autoreload_app(py_file):
         assert r2.status_code == 200
         assert "<title>B</title>" in r2.content.decode('utf-8')
 
+
+@linux_only
+def test_autoreload_app_local_module(py_files):
+    py_file1, py_file2 = py_files
+    app_name = os.path.basename(py_file1.name)[:-3]
+    mod_name = os.path.basename(py_file2.name)[:-3]
+    app = f"import panel as pn; from {mod_name} import title; pn.Row('# Example').servable(title=title)"
+    write_file(app, py_file1.file)
+    write_file("title = 'A'", py_file2.file)
+
+    with run_panel_serve(["--port", "0", '--autoreload', py_file1.name]) as p:
+        port = wait_for_port(p.stdout)
+        r = requests.get(f"http://localhost:{port}/{app_name}")
+        assert r.status_code == 200
+        assert "<title>A</title>" in r.content.decode('utf-8')
+
+        write_file("title = 'B'", py_file2.file)
+        py_file2.file.close()
+        time.sleep(1)
+
+        r2 = requests.get(f"http://localhost:{port}/{app_name}")
+        assert r2.status_code == 200
+        assert "<title>B</title>" in r2.content.decode('utf-8')
+
+
 @linux_only
 def test_serve_admin(py_file):
     app = "import panel as pn; pn.Row('# Example').servable(title='A')"
