@@ -441,6 +441,34 @@ def test_layout_clone_objects_in_kwargs(panel):
     assert clone.sizing_mode == 'stretch_height'
 
 
+@pytest.mark.parametrize('panel', [Column, Row])
+def test_layout_children_not_copied(panel):
+    layout = panel()
+
+    objects = [Markdown(), Markdown()]
+    layout.objects = objects
+
+    assert layout.objects is objects
+
+
+@pytest.mark.parametrize('panel', [Column, Row])
+def test_layout_children_not_mutated_inplace(panel):
+    layout = panel()
+
+    objects = [Div(), Div()]
+    layout.objects = objects
+
+    assert layout.objects is not objects
+    assert layout.objects[0].object is objects[0]
+    assert layout.objects[1].object is objects[1]
+
+    layout[:] = objects
+
+    assert layout.objects is not objects
+    assert layout.objects[0].object is objects[0]
+    assert layout.objects[1].object is objects[1]
+
+
 @pytest.mark.parametrize('panel', [Column, Row])
 def test_layout_clone_objects_in_args_and_kwargs(panel):
     div1 = Div()
