@@ -32,8 +32,6 @@ import numpy as np
 import param
 
 from bokeh.models import ColumnDataSource, FixedTicker, Tooltip
-from bokeh.plotting import figure
-from tqdm.asyncio import tqdm as _tqdm
 
 from .._param import Align
 from ..io.resources import CDN_DIST
@@ -54,6 +52,10 @@ if TYPE_CHECKING:
     from bokeh.document import Document
     from bokeh.model import Model
     from pyviz_comms import Comm
+try:
+    from tqdm.asyncio import tqdm as _tqdm
+except ImportError:
+    _tqdm = None
 
 RED   = "#d9534f"
 GREEN = "#5cb85c"
@@ -734,6 +736,7 @@ class Dial(ValueIndicator):
         return annulus_data, needle_data, threshold_data, text_data
 
     def _get_model(self, doc, root=None, parent=None, comm=None):
+        from bokeh.plotting import figure
         properties = self._get_properties(doc)
         model = figure(
             x_range=(-1,1), y_range=(-1,1), tools=[],
@@ -743,6 +746,11 @@ class Dial(ValueIndicator):
         model.xaxis.visible = False
         model.yaxis.visible = False
         model.grid.visible = False
+        if self.background in (None, "transparent"):
+            model.background_fill_alpha = 0
+        else:
+            model.background_fill_alpha = 1
+            model.background_fill_color = self.background
 
         annulus, needle, threshold, text = self._get_data(properties)
 
@@ -950,6 +958,8 @@ class LinearGauge(ValueIndicator):
         )
 
     def _get_model(self, doc, root=None, parent=None, comm=None):
+        from bokeh.plotting import figure
+
         params = self._get_properties(doc)
         model = figure(
             outline_line_color=None, toolbar_location=None, tools=[],
@@ -1212,9 +1222,11 @@ MARGIN = {
 
 
 
-class ptqdm(_tqdm):
+class ptqdm(_tqdm or object):
 
     def __init__(self, *args, **kwargs):
+        if _tqdm is None:
+            raise ImportError("tqdm is required for this indicator")
         self._indicator = kwargs.pop('indicator')
         super().__init__(*args, **kwargs)
 
